# Setup ObsidianHtml

This wizard will help you configure ObsidianHtml correctly (or at least avoid common mistakes).

Initializing...

## Select Vault

Entrypoint
Failed to load setting
i
The note that is to become the homepage of your new site. In default mode, ObsidianHtml will start compiling your website starting with this note, and following any links to any other note. This note has to be in the vault selected above.

## Outputs

Markdown output folder
Failed to load setting
i
When ObsidianHtml converts your notes, it first compiles proper markdown notes. This setting determines where those files are exported to.